current_worktree

Function current_worktree 

pub fn current_worktree(repo: &Repository) -> Result<WorktreeDescriptor>
Return the worktree that contains the current working directory.

Returns WorktreeError::NotInWorktree if the current directory is not inside any registered worktree.