empty_commit

Function empty_commit 

pub fn empty_commit(repo: &Repository) -> Result<Oid>
Create an empty initial commit on HEAD with no parents.

Used when initialising a new bare repository to ensure HEAD points to a valid commit. Returns WorktreeError::NonEmptyIndex if the index is not empty when called.