pub fn find_worktree(
repo: &Repository,
name: &str,
) -> Result<WorktreeDescriptor>Expand description
Find a worktree by its name or by its branch name.
Returns WorktreeError::NotFound if no matching worktree exists.
pub fn find_worktree(
repo: &Repository,
name: &str,
) -> Result<WorktreeDescriptor>Find a worktree by its name or by its branch name.
Returns WorktreeError::NotFound if no matching worktree exists.