get_repo

Function get_repo 

pub fn get_repo(path: Option<PathBuf>) -> Result<Repository>
Discover and open a bare repository from path (or the current directory).

If the discovered repository is a linked worktree, follows the commondir pointer back to the bare repo. Returns RepoError::NotBare if the repository is not bare.