pub fn gh_stack_divergent_stack_numbers(repo: &Repository) -> Vec<u64>Expand description
Stack numbers that appear in more than one gh-stack source, only reachable in degraded
(union-read) mode. For doctor’s GhStackDivergentStacks check.
pub fn gh_stack_divergent_stack_numbers(repo: &Repository) -> Vec<u64>Stack numbers that appear in more than one gh-stack source, only reachable in degraded
(union-read) mode. For doctor’s GhStackDivergentStacks check.