pub fn preferred_remote_order(repo: &Repository) -> Vec<String>Expand description
Returns remotes in preferred order: upstream first, then origin, then all others in configuration order (the sort is stable).
pub fn preferred_remote_order(repo: &Repository) -> Vec<String>Returns remotes in preferred order: upstream first, then origin, then all others in configuration order (the sort is stable).