pub struct PrMetadata {
pub number: u32,
pub title: String,
pub author: String,
pub head_ref: String,
pub base_ref: String,
pub is_fork: bool,
pub fork_owner: Option<String>,
pub fork_url: Option<String>,
}Expand description
PR metadata fetched from the gh CLI.
Fields
number: u32PR number.
title: StringPR title.
GitHub login of the PR author.
head_ref: StringName of the branch that the PR was created from.
base_ref: StringName of the branch the PR targets.
is_fork: boolTrue if the PR comes from a forked repository.
fork_owner: Option<String>GitHub login of the fork owner, if this is a fork PR.
fork_url: Option<String>Clone URL of the fork repository, if this is a fork PR.