init

Function init 

pub fn init(path: PathBuf) -> Result<Repository>
Initialise a new bare repository at path in the worktrees layout.

Creates a bare repository, adds an initial empty commit so that HEAD is valid, then converts to the worktrees layout (see convert_to_bare).